import React, {Fragment} from 'react';
import PropTypes from 'prop-types';
import Select, {components} from 'react-select';
import {
    FormGroup,
    Label,
    Tooltip,
    Row,
    Col, UncontrolledTooltip
} from 'reactstrap';
import Loading from '../Loading';
import {TextField} from './index';
import {
    noPadding,
    styleInvalid,
    styleValid,
    small,
    flexR,
    toolTip,
    padding,
    toolTipIcon,
    smallAlt
} from '../common/styles/index';
const customComponents = {
    NoOptionsMessage: props => (
        <Tooltip content="noMessageOption">
            <components.NoOptionsMessage {...props}>
                No se encontraron resultados&nbsp;
            </components.NoOptionsMessage>
            &nbsp;
        </Tooltip>
    )
};
const SelectInput = ({
                         label,
                         control,
                         defaultOption,
                         disabled,
                         filterOption,
                         getValue,
                         onChange,
                         onChangeOthers,
                         onInputChange,
                         options,
                         placeholder,
                         value,
                         valueOthers,
                         searching,
                         helpText,
                         error,
                         supportsWriteOthers
                     }) => (
    <FormGroup>
        <Row style={noPadding}>
            <Col style={noPadding}>
                <Fragment>
                    <Label
                        style={{...small, ...noPadding, ...flexR,...padding}}>
                        <p
                            style={noPadding}>
                            {label+" "}
                        </p>
                        {helpText && (
                            <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+control}>
                                {String.fromCharCode(0x24D8)}
                            </p>
                        )}

                    </Label>
                    <Select
                        id={control}
                        value={getValue ? getValue(value, options) : value}
                        defaultValue={defaultOption ? {value: '', label: '[Todos]'} : false}
                        onChange={onChange}
                        onInputChange={onInputChange}
                        options={options}
                        components={customComponents}
                        filterOption={filterOption}
                        isSearchable
                        isClearable
                        isDisabled={disabled}
                        placeholder={placeholder}
                        clearValueText="Limpiar Filtro"
                        isLoading={searching}
                    />
                    {helpText && (
                        <UncontrolledTooltip
                            placement="top"
                            target={'ref'+control}
                            style={toolTip}>
                                {helpText}
                        </UncontrolledTooltip>
                    )}
                    {searching && (
                        <Loading
                            label="Estamos buscando tu consulta"
                        />
                    )}
                    {
                        (error.message !== '')  && (<p style={error.status === 'valid' ? styleValid : styleInvalid}>
                        {error.message}
                        </p>)}

                </Fragment>
            </Col>
            {
                supportsWriteOthers && (
                    <div>
                        &nbsp;&nbsp;
                    </div>
                )
            }
            {supportsWriteOthers  && (
                <Col style={noPadding}>
                    <TextField
                        name={`${control}Others`}
                        label={`Otro ${label}`}
                        value={valueOthers}
                        helpText={null}
                        disabled={value.value !== 'idAnother'}
                        onChange={e => onChangeOthers(e)}
                        error={error}
                     />
                </Col>
            )}
        </Row>

    </FormGroup>
);

SelectInput.propTypes = {
    label: PropTypes.string.isRequired,
    control: PropTypes.string.isRequired,
    options: PropTypes.arrayOf(PropTypes.shape({})).isRequired,
    onChange: PropTypes.func.isRequired,
    onChangeOthers: PropTypes.func.isRequired,
    valueOthers: PropTypes.string,
    value: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
    ]),
    onInputChange: PropTypes.func,
    getValue: PropTypes.func,
    defaultOption: PropTypes.bool,
    placeholder: PropTypes.string,
    disabled: PropTypes.bool,
    filterOption: PropTypes.oneOfType([
        PropTypes.any
    ]),
    searching: PropTypes.bool,
    helpText: PropTypes.bool,
    error: PropTypes.shape
};

SelectInput.defaultProps = {
    defaultOption: false,
    placeholder: '[Seleccione]',
    value: '',
    valueOthers: '',
    onInputChange: null,
    getValue: null,
    disabled: false,
    filterOption: null,
    searching: false,
    helpText: null,
    error: {
        status: null
    }
};

export default SelectInput;
