import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, Input, FormGroup, FormFeedback, UncontrolledTooltip
} from 'reactstrap';
import {small, flexR, noPadding, toolTip, padding, toolTipIcon, smallAlt} from '../common/styles/index';
class TextField extends Component {
    static propTypes = {
        onChange: PropTypes.func.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        value: PropTypes.string,
        placeholder: PropTypes.string,
        type: PropTypes.string.isRequired,
        helpText: PropTypes.string,
        disabled: PropTypes.bool,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        error: PropTypes.shape(),
        onKeyPress: PropTypes.func
    };

    static defaultProps = {
        value: null,
        helpText: null,
        minLength: null,
        maxLength: null,
        error: {
            status: null
        },
        disabled: false,
        onKeyPress: null
    };

    handleChange({target}) {
        if (this.props.value === target.value) {
            return;
        }
        this.props.onChange({target});
    }

    render() {
        const {
            name, label, value, placeholder, type, helpText, disabled, error, minLength, maxLength
        } = this.props;
        return (
            <FormGroup>
                <Label
                    style={{...small, ...noPadding, ...flexR, ...padding}}>
                        <p
                        style={noPadding}>
                            {label+" "}
                        </p>
                    {helpText && (
                        <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+name}>
                            {String.fromCharCode(0x24D8)}
                        </p>
                    )}
                </Label>
                <Input
                    valid={error.status === 'valid' ? true : null}
                    invalid={error.status === 'invalid' ? true : null}
                    id={name}
                    placeholder={placeholder}
                    name={name}
                    type={type}
                    value={value}
                    minLength={minLength ? minLength : null}
                    maxLength={maxLength ? maxLength : null}
                    autoComplete="off"
                    disabled={disabled}
                    onChange={e => this.handleChange(e)}
                    onKeyPress={this.props.onKeyPress}
                />
                <FormFeedback valid={error.status === 'valid' ? true : null}>
                    {error.message}
                </FormFeedback>
                {helpText && (
                    <UncontrolledTooltip placement="top" target={'ref'+name}
                        style={toolTip}>
                        {helpText}
                    </UncontrolledTooltip>
                )}
            </FormGroup>
        );
    }
}

export default TextField;
